@@ -6,11 +6,11 @@ from django.core.exceptions import FieldDoesNotExist, FieldError
 from django.db import connection
 from django.db.models import (
     BooleanField, Case, CharField, Count, DateTimeField, Exists,
-    ExpressionWrapper, F, Func, IntegerField, Max, NullBooleanField, OuterRef,
-    Q, Subquery, Sum, Value, When,
+    ExpressionWrapper, F, FloatField, Func, IntegerField, Max,
+    NullBooleanField, OuterRef, Q, Subquery, Sum, Value, When,
 )
 from django.db.models.expressions import RawSQL
-from django.db.models.functions import ExtractYear, Length, Lower
+from django.db.models.functions import Length, Lower
 from django.test import TestCase, skipUnlessDBFeature
 
 from .models import (
@@ -26,6 +26,7 @@ def cxOracle_py3_bug(func):
     we mark them as expected failures until someone fixes them in #23843.
     """
     from unittest import expectedFailure
+
     from django.db import connection
     return expectedFailure(func) if connection.vendor == 'oracle' else func
 
@@ -170,6 +171,34 @@ class NonAggregateAnnotationTestCase(TestCase):
             self.assertEqual(book.is_book, 1)
             self.assertEqual(book.rating_count, 1)
 
+    def test_combined_expression_annotation_with_aggregation(self):
+        book = Book.objects.annotate(
+            combined=ExpressionWrapper(Value(3) * Value(4), output_field=IntegerField()),
+            rating_count=Count('rating'),
+        ).first()
+        self.assertEqual(book.combined, 12)
+        self.assertEqual(book.rating_count, 1)
+
+    def test_combined_f_expression_annotation_with_aggregation(self):
+        book = Book.objects.filter(isbn='159059725').annotate(
+            combined=ExpressionWrapper(F('price') * F('pages'), output_field=FloatField()),
+            rating_count=Count('rating'),
+        ).first()
+        self.assertEqual(book.combined, 13410.0)
+        self.assertEqual(book.rating_count, 1)
+
+    @skipUnlessDBFeature('supports_boolean_expr_in_select_clause')
+    def test_q_expression_annotation_with_aggregation(self):
+        book = Book.objects.filter(isbn='159059725').annotate(
+            isnull_pubdate=ExpressionWrapper(
+                Q(pubdate__isnull=True),
+                output_field=BooleanField(),
+            ),
+            rating_count=Count('rating'),
+        ).first()
+        self.assertEqual(book.isnull_pubdate, False)
+        self.assertEqual(book.rating_count, 1)
+
     def test_aggregate_over_annotation(self):
         agg = Author.objects.annotate(other_age=F('age')).aggregate(otherage_sum=Sum('other_age'))
         other_agg = Author.objects.aggregate(age_sum=Sum('age'))
@@ -212,7 +241,7 @@ class NonAggregateAnnotationTestCase(TestCase):
         lengths = Employee.objects.annotate(
             name_len=Length('first_name'),
         ).distinct('name_len').values_list('name_len', flat=True)
-        self.assertSequenceEqual(lengths, [3, 7, 8])
+        self.assertCountEqual(lengths, [3, 7, 8])
 
     def test_filter_annotation(self):
         books = Book.objects.annotate(
@@ -635,27 +664,8 @@ class NonAggregateAnnotationTestCase(TestCase):
             datetime.date(2008, 11, 3),
         ])
 
-    @skipUnlessDBFeature('supports_subqueries_in_group_by')
-    def test_annotation_subquery_and_aggregate_values_chaining(self):
-        qs = Book.objects.annotate(
-            pub_year=ExtractYear('pubdate')
-        ).values('pub_year').annotate(
-            top_rating=Subquery(
-                Book.objects.filter(
-                    pubdate__year=OuterRef('pub_year')
-                ).order_by('-rating').values('rating')[:1]
-            ),
-            total_pages=Sum('pages'),
-        ).values('pub_year', 'total_pages', 'top_rating')
-        self.assertCountEqual(qs, [
-            {'pub_year': 1991, 'top_rating': 5.0, 'total_pages': 946},
-            {'pub_year': 1995, 'top_rating': 4.0, 'total_pages': 1132},
-            {'pub_year': 2007, 'top_rating': 4.5, 'total_pages': 447},
-            {'pub_year': 2008, 'top_rating': 4.0, 'total_pages': 1178},
-        ])
-
     @skipIf(
-        connection.vendor == 'mysql',
+        connection.vendor == 'mysql' and 'ONLY_FULL_GROUP_BY' in connection.sql_mode,
         'GROUP BY optimization does not work properly when ONLY_FULL_GROUP_BY '
         'mode is enabled on MySQL, see #31331.',
     )
