@@ -4,24 +4,32 @@ from unittest import mock
 
 from django.core.exceptions import ImproperlyConfigured
 from django.db import DatabaseError, connection, connections
+from django.db.backends.base.base import BaseDatabaseWrapper
 from django.test import TestCase, override_settings
 
 
 @unittest.skipUnless(connection.vendor == 'postgresql', 'PostgreSQL tests')
 class Tests(TestCase):
+    databases = {'default', 'other'}
 
-    def test_nodb_connection(self):
+    def test_nodb_cursor(self):
         """
-        The _nodb_connection property fallbacks to the default connection
-        database when access to the 'postgres' database is not granted.
+        The _nodb_cursor() fallbacks to the default connection database when
+        access to the 'postgres' database is not granted.
         """
+        orig_connect = BaseDatabaseWrapper.connect
+
         def mocked_connect(self):
             if self.settings_dict['NAME'] is None:
                 raise DatabaseError()
-            return ''
+            return orig_connect(self)
 
-        nodb_conn = connection._nodb_connection
-        self.assertIsNone(nodb_conn.settings_dict['NAME'])
+        with connection._nodb_cursor() as cursor:
+            self.assertIs(cursor.closed, False)
+            self.assertIsNotNone(cursor.db.connection)
+            self.assertIsNone(cursor.db.settings_dict['NAME'])
+        self.assertIs(cursor.closed, True)
+        self.assertIsNone(cursor.db.connection)
 
         # Now assume the 'postgres' db isn't available
         msg = (
@@ -39,9 +47,13 @@ class Tests(TestCase):
                     'settings_dict',
                     {**connection.settings_dict, 'NAME': 'postgres'},
                 ):
-                    nodb_conn = connection._nodb_connection
-        self.assertIsNotNone(nodb_conn.settings_dict['NAME'])
-        self.assertEqual(nodb_conn.settings_dict['NAME'], connections['other'].settings_dict['NAME'])
+                    with connection._nodb_cursor() as cursor:
+                        self.assertIs(cursor.closed, False)
+                        self.assertIsNotNone(cursor.db.connection)
+        self.assertIs(cursor.closed, True)
+        self.assertIsNone(cursor.db.connection)
+        self.assertIsNotNone(cursor.db.settings_dict['NAME'])
+        self.assertEqual(cursor.db.settings_dict['NAME'], connections['other'].settings_dict['NAME'])
 
     def test_database_name_too_long(self):
         from django.db.backends.postgresql.base import DatabaseWrapper
@@ -102,8 +114,8 @@ class Tests(TestCase):
 
         try:
             # Open a database connection.
-            new_connection.cursor()
-            self.assertFalse(new_connection.get_autocommit())
+            with new_connection.cursor():
+                self.assertFalse(new_connection.get_autocommit())
         finally:
             new_connection.close()
 
@@ -117,10 +129,10 @@ class Tests(TestCase):
             ISOLATION_LEVEL_READ_COMMITTED as read_committed,
             ISOLATION_LEVEL_SERIALIZABLE as serializable,
         )
+
         # Since this is a django.test.TestCase, a transaction is in progress
         # and the isolation level isn't reported as 0. This test assumes that
         # PostgreSQL is configured with the default isolation level.
-
         # Check the level on the psycopg2 connection, not the Django wrapper.
         default_level = read_committed if psycopg2.__version__ < '2.7' else None
         self.assertEqual(connection.connection.isolation_level, default_level)
@@ -137,9 +149,12 @@ class Tests(TestCase):
 
     def test_connect_no_is_usable_checks(self):
         new_connection = connection.copy()
-        with mock.patch.object(new_connection, 'is_usable') as is_usable:
-            new_connection.connect()
-        is_usable.assert_not_called()
+        try:
+            with mock.patch.object(new_connection, 'is_usable') as is_usable:
+                new_connection.connect()
+            is_usable.assert_not_called()
+        finally:
+            new_connection.close()
 
     def _select(self, val):
         with connection.cursor() as cursor:
